@@ -57,8 +57,8 @@ class UpdateEnv(gym.Env):
     #-----------------------------------------------------------------------------------
     # e=e, t=0
     # observe new patients (Xs_e(0), Xa_e(0))
-    pat_e0= np.hstack([np.ones((self.size, 1)), np.random.uniform(-4, 4, size=(self.size,2))]) #shape (size, 3), (1, Xs, Xa)
-    #pat_e0= np.hstack([np.ones((self.size, 1)), truncnorm.rvs(a=0, b= 100,size=(self.size,2))]) #shape (size, 3), (1, Xs, Xa)
+    #pat_e0= np.hstack([np.ones((self.size, 1)), np.random.uniform(-4, 4, size=(self.size,2))]) #shape (size, 3), (1, Xs, Xa)
+    pat_e0= np.hstack([np.ones((self.size, 1)), truncnorm.rvs(a=0, b= 100,size=(self.size,2))]) #shape (size, 3), (1, Xs, Xa)
     
     # compute rho_0(Xs_e(0), Xa_e(0)) - we're using covariates at e and thetas at e-1
     # well thetas are actually actions
@@ -118,8 +118,8 @@ class UpdateEnv(gym.Env):
 
     # e=0, t=0
     # observe self.patients (from reset function, self.patients) (Xs(0), Xa(0))
-    self.patients = np.random.uniform(-4, 4, size=(self.size,2))
-    #self.patients = truncnorm.rvs(a=0, b= 100,size=(self.size,2)) #shape (size, 2), 1st columns is Xs, second is Xa                        
+    #self.patients = np.random.uniform(-4, 4, size=(self.size,2))
+    self.patients = truncnorm.rvs(a=0, b= 100,size=(self.size,2)) #shape (size, 2), 1st columns is Xs, second is Xa                        
     
     #-----------------------------------------------------------------------------------
     #e=0, t=1    
